summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTim Smith <tsmith84@gmail.com>2019-06-26 11:54:07 -0700
committerTim Smith <tsmith84@gmail.com>2019-06-26 11:54:07 -0700
commit7258235b6e08f6b18aca3418da3ad6faabe4bb42 (patch)
treec82c4f5ccd8bdc66adbd016e593e96bcdd51a40f
parent9bf2c1ec0b04a8c309158fbc9f26cdbe3bd98bb1 (diff)
downloadchef-7258235b6e08f6b18aca3418da3ad6faabe4bb42.tar.gz
Chef Client -> Chef Infra Client
Signed-off-by: Tim Smith <tsmith@chef.io>
-rwxr-xr-xdocs.rb24
1 files changed, 12 insertions, 12 deletions
diff --git a/docs.rb b/docs.rb
index 52c4f48f92..c68e7c452e 100755
--- a/docs.rb
+++ b/docs.rb
@@ -135,7 +135,7 @@ def boilerplate_content
``sensitive``
**Ruby Type:** true, false | **Default Value:** ``false``
- Ensure that sensitive resource data is not logged by the chef-client.
+ Ensure that sensitive resource data is not logged by the Chef Infra Client.
.. end_tag
@@ -152,13 +152,13 @@ def boilerplate_content
.. tag resources_common_notification_timers
- A timer specifies the point during the Chef Client run at which a notification is run. The following timers are available:
+ A timer specifies the point during the Chef Infra Client run at which a notification is run. The following timers are available:
``:before``
Specifies that the action on a notified resource should be run before processing the resource block in which the notification is located.
``:delayed``
- Default. Specifies that a notification should be queued up, and then executed at the end of the Chef Client run.
+ Default. Specifies that a notification should be queued up, and then executed at the end of the Chef Infra Client run.
``:immediate``, ``:immediately``
Specifies that a notification should be run immediately, per resource notified.
@@ -201,13 +201,13 @@ def boilerplate_content
.. tag resources_common_notification_timers
- A timer specifies the point during the Chef Client run at which a notification is run. The following timers are available:
+ A timer specifies the point during the Chef Infra Client run at which a notification is run. The following timers are available:
``:before``
Specifies that the action on a notified resource should be run before processing the resource block in which the notification is located.
``:delayed``
- Default. Specifies that a notification should be queued up, and then executed at the end of the Chef Client run.
+ Default. Specifies that a notification should be queued up, and then executed at the end of the Chef Infra Client run.
``:immediate``, ``:immediately``
Specifies that a notification should be run immediately, per resource notified.
@@ -229,17 +229,17 @@ def boilerplate_content
.. tag resources_common_guards
- A guard property can be used to evaluate the state of a node during the execution phase of the chef-client run. Based on the results of this evaluation, a guard property is then used to tell the chef-client if it should continue executing a resource. A guard property accepts either a string value or a Ruby block value:
+ A guard property can be used to evaluate the state of a node during the execution phase of the Chef Infra Client run. Based on the results of this evaluation, a guard property is then used to tell the Chef Infra Client if it should continue executing a resource. A guard property accepts either a string value or a Ruby block value:
* A string is executed as a shell command. If the command returns ``0``, the guard is applied. If the command returns any other value, then the guard property is not applied. String guards in a **powershell_script** run Windows PowerShell commands and may return ``true`` in addition to ``0``.
* A block is executed as Ruby code that must return either ``true`` or ``false``. If the block returns ``true``, the guard property is applied. If the block returns ``false``, the guard property is not applied.
- A guard property is useful for ensuring that a resource is idempotent by allowing that resource to test for the desired state as it is being executed, and then if the desired state is present, for the chef-client to do nothing.
+ A guard property is useful for ensuring that a resource is idempotent by allowing that resource to test for the desired state as it is being executed, and then if the desired state is present, for the Chef Infra Client to do nothing.
.. end_tag
.. tag resources_common_guards_properties
- The following properties can be used to define a guard that is evaluated during the execution phase of the chef-client run:
+ The following properties can be used to define a guard that is evaluated during the execution phase of the Chef Infra Client run:
``not_if``
Prevent a resource from executing when the condition returns ``true``.
@@ -259,7 +259,7 @@ template = %{=====================================================
<%= bolded_description(@name, @description) %>
<%= note_text(@description) %>
<% unless @introduced.nil? %>
**New in Chef Client <%= @introduced %>.**
<% end %>
Syntax
=====================================================
@@ -273,7 +273,7 @@ where:
* ``<%= @name %>`` is the resource.
* ``name`` is the name given to the resource block.
* ``action`` identifies which steps the chef-client will take to bring the node into the desired state.
<% unless @property_list.nil? %>* <%= @property_list %><% end %>
Actions
@@ -287,7 +287,7 @@ The <%= @name %> resource has the following actions:
``:nothing``
.. tag resources_common_actions_nothing
- This resource block does not act unless notified by another resource to take action. Once notified, this resource block either runs immediately or is queued up to run at the end of the Chef Client run.
+ This resource block does not act unless notified by another resource to take action. Once notified, this resource block either runs immediately or is queued up to run at the end of the Chef Infra Client run.
.. end_tag
@@ -300,7 +300,7 @@ The <%= @name %> resource has the following properties:
**Ruby Type:** <%= friendly_types_list(p['is']) %><% unless pretty_default(p['default']).nil? %> | **Default Value:** ``<%= pretty_default(p['default']) %>``<% end %><% if p['required'] %> | ``REQUIRED``<% end %><% if p['deprecated'] %> | ``DEPRECATED``<% end %><% if p['name_property'] %> | **Default Value:** ``The resource block's name``<% end %>
<%= p['description'] %>
-<% unless p['introduced'].nil? %>\n *New in Chef Client <%= p['introduced'] %>.*<% end %>
+<% unless p['introduced'].nil? %>\n *New in Chef Infra Client <%= p['introduced'] %>.*<% end %>
<% end %>
<% if @properties.empty? %>This resource does not have any properties.\n<% end %>
<%= boilerplate_content %>
@@ -259,7 +259,7 @@ template = %{=====================================================
<%= note_text(@description) %>
<% unless @introduced.nil? %>
-**New in Chef Client <%= @introduced %>.**
+**New in Chef Infra Client <%= @introduced %>.**
<% end %>
Syntax
@@ -273,7 +273,7 @@ where:
* ``<%= @name %>`` is the resource.
* ``name`` is the name given to the resource block.
-* ``action`` identifies which steps the chef-client will take to bring the node into the desired state.
+* ``action`` identifies which steps the Chef Infra Client will take to bring the node into the desired state.
<% unless @property_list.nil? %>* <%= @property_list %><% end %>
Actions